#[non_exhaustive]pub enum Error {
CapacityOverflow,
OverGrow {
to_grow: usize,
available: usize,
},
AllocError {
layout: Layout,
/* private fields */
},
System(Error),
}Expand description
Errors that can occur during memory operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CapacityOverflow
Error due to the computed capacity exceeding the maximum
(usually isize::MAX bytes).
Examples
grow more than isize::MAX bytes:
let mut mem = Alloc::new(Global);
assert!(matches!(mem.grow_filled(usize::MAX, 0u64), Err(Error::CapacityOverflow)));OverGrow
Cannot grow because the requested size exceeds available capacity.
AllocError
The memory allocator returned an error
System(Error)
An I/O or system-level error.